@@ -13,7 +13,7 @@ class Process;
 
 class Process : public TQObject {
 	Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
 	Process();
@@ -26,11 +26,11 @@ public:
 	void start(bool block=true);
 
 protected:
-	KProcess* _process;
+	TDEProcess* _process;
 	TQString _buffer;
 
 protected slots:
-	void slotProcessOutput(KProcess* process, char* buffer, int buflen);
+	void slotProcessOutput(TDEProcess* process, char* buffer, int buflen);
 };
 
 
